import React, { ReactNode } from 'react';
import { Metadata } from 'next';
import { unstable_setRequestLocale } from 'next-intl/server';
import { notFound } from 'next/navigation';
import { ConfigProvider } from 'antd';
import { AntdRegistry } from '@ant-design/nextjs-registry';
import theme from '../../constants/theme';
import { ALLOWED_LOCALES } from '../../constants/locale';
import { Header, Footer } from '../../components/Page';

import { GoogleOAuthProvider } from '@react-oauth/google';
import { SessionProvider } from "next-auth/react"

type LayoutProps = {
    children: ReactNode;
    params: { locale: string };
};

export function generateStaticParams() {
    return ALLOWED_LOCALES.map((locale) => ({ locale }));
}

export const metadata: Metadata = {
    title: 'Bbuddy'
};

export default function LocaleLayout({ children, params: { locale } }: LayoutProps) {
    if (!ALLOWED_LOCALES.includes(locale as any)) notFound();

    unstable_setRequestLocale(locale);

    return (
        <AntdRegistry>
            <GoogleOAuthProvider clientId='909563069647-03rivr8k1jmirf382bcfehegamthcfg4.apps.googleusercontent.com'>
                <ConfigProvider theme={theme}>
                <div className="b-wrapper">
                    <div className="b-content">
                        <Header locale={locale} />
                        {children}
                    </div>
                    <Footer locale={locale} />
                </div>
                </ConfigProvider>
            </GoogleOAuthProvider>    
        </AntdRegistry>
    );
};
